Learn R Programming

GPArotateDF (version 2025.7-1)

00.GPArotateDF: Derivative-Free Gradient Projection Algorithms for Factor Rotation

Description

Derivative-Free GPA Rotation for Factor Analysis

The GPArotateDF package contains functions for the rotation of factor loadings matrices without the need for deriving gradients. Both orthogonal and oblique rotation algorithms are available. Additionally, a number of rotation criteria are provided. The GP algorithms minimize the rotation criterion function, and provide the corresponding rotation matrix. For oblique rotation, the covariance / correlation matrix of the factors is also provided. The derivartive-free rotation method implemented in this package is described in Jennrich (2004). The GPArotation package is based on Bernaards and Jennrich (2005).

Package:GPArotateDF
Depends:R (>= 2.0.0)
License:GPL Version 2.
Imports:GPArotation

Index of functions:

Derivative-Free Gradient Projection Rotation Algorithms

GPForth.dfOrthogonal rotation function
GPFoblq.dfOblique rotation function

Rotations

cubimax.dfCubimax rotation
fssQ.dfOblique Forced Simple Structure rotation
fssT.dfOrthogonal Forced Simple Structure rotation

ff routines to compute value of the criterion

ff.bentlerBentler's Invariant Pattern Simplicity ff
ff.cfCrawford-Ferguson Family ff
ff.cubimaxCubimax ff
ff.entropyMinimum Entropy ff
ff.geominGeomin ff
ff.infomaxInfomax ff
ff.oblimaxOblimax ff
ff.pstPartially Specified Target ff
ff.quartimaxQuartimax ff
ff.quartiminQuartimin ff
ff.simplimaxSimplimax ff
ff.fssForced Simple Structure ff
ff.targetTarget ff
ff.varimaxVarimax ff

Utility functions

NormalizingWeightKaiser normalization (not exported from NAMESPACE)

Arguments

Author

Coen A. Bernaards and Robert I. Jennrich

References

Bernaards, C.A. and Jennrich, R.I. (2005) Gradient Projection Algorithms and Software for Arbitrary Rotation Criteria in Factor Analysis. Educational and Psychological Measurement, 65, 676--696.

Jennrich, R.I. (2004). Derivative free gradient projection algorithms for rotation. Psychometrika, 69, 475--480.

See Also

GPForth.df, GPFoblq.df