Learn R Programming

GPArotateDF (version 2025.7-1)

Griffith: Example Data from Mulaik (2018)

Description

Example from Mulaik, S.A. (2018) Fundamentals of Common Analysis in Irwing, P., Booth, T., Hughes, D. J. (2018). The Wiley Handbook of Psychometric Testing, 2 Volume Set: A Multidisciplinary Reference on Survey, Scale and Test Development. [VitalSource Bookshelf 10.2.0]. Retrieved from vbk://9781118489703 See Part II, Table 8.5 (p.225) and Table 8.6 (p.235)

Usage

data(Griffith)

Arguments

Format

The object Griffith is a matrix.

Details

The object Griffith is loaded from the data file Griffith.

See Also

ff.varimax